django-livewatch documentation
==============================

livewatch.de integration for Django projects.

Features
========

* `celery <https://github.com/celery/celery>`_ integration
* `django-rq <https://github.com/ui/django-rq>`_ integration

Usage
=====

.. toctree::
   :maxdepth: 3

   installation
   configuration
   usage
   extending_livewatch
   contribution
   changelog

Api documentation
=================

.. toctree::
   :maxdepth: 2

   modules/modules


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

